<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Imports\ClientImport;
use App\Models\Template;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Session;
use Maatwebsite\Excel\Facades\Excel;

class TemplateController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $data = getInformationData('Template');
        return view('admin.templates.index', compact('data'));
    }

    public function store(Request $request)
    {
        try {
            Template::create([
                'user_id' => auth('web')->check() ? getUserType() : null,
                'subscriber_id' => auth('subscriber')->check() ? getUserType() : null,
                'name' => $request->name,
                'language' => $request->language,
            ]);
            Session::flash('message', 'تم الحفظ بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->back();
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    public function update(Request $request, string $id)
    {
        try {
            Template::findorfail($request->id)->update([
                'user_id' => auth('web')->check() ? getUserType() : null,
                'subscriber_id' => auth('subscriber')->check() ? getUserType() : null,
                'name' => $request->name,
                'language' => $request->language,
            ]);
            Session::flash('message', 'تم التعديل بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->back();
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    public function destroy(string $id)
    {
        try {
            Template::destroy(\request()->id);
            Session::flash('message', 'تم الحذف بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->back();
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    public function uploadFile()
    {
        return view('admin.uploadfile.index');
    }

    public function uploadFileInSystem(Request $request)
    {
        $file = $request->file('excel');
        Excel::import(new ClientImport, $file);
        Session::flash('message', 'جاري رفع البيانات وسيتم الابلاغ عند الانتهاء');
        Session::flash('alert-class', 'alert-success');
        return redirect()->back();

    }
}
