<?php

use App\Models\BootButton;
use App\Models\BootList;
use App\Models\Template;
use Illuminate\Support\Facades\Http;

// functions helpers Whatsapp cloud Apis


if (!function_exists('baseUrl')) {
    function baseUrl($Version, $PhoneID, $token, $data)
    {
        $response = Http::withOptions([
            'verify' => false,
        ])->withHeaders([
            "Authorization" => "Bearer " . $token,
            "Content-Type" => "application/json",
        ])->withBody(json_encode($data), 'application/json')->post('https://graph.facebook.com/' . $Version . '/' . $PhoneID . '/messages');

        if ($response->status() == 200) {
            return response()->json("data Send", 200);
        } else {
            return response()->json("data Error Send Messages", 400);
        }
    }
}

if (!function_exists('sendMessagesSingle')) {
    function sendMessages($Version, $PhoneID, $token, $phone, $messages)
    {
        $data = [
            "messaging_product" => "whatsapp",
            "recipient_type" => "individual",
            "to" => $phone,
            "type" => "text",
            "text" => [
                "preview_url" => false,
                "body" => $messages
            ]
        ];

        if ($data) {
            $responseData = baseUrl($Version, $PhoneID, $token, $data);
            if ($responseData) {
                return response()->json("data Send Messages", 200);
            } else {
                return response()->json("data Error Send Messages", 400);
            }
        }
        return false;
    }
}

if (!function_exists('sendReplyMessagesSingle')) {
    function sendReplyMessagesSingle($Version, $PhoneID, $token, $messages, $phone, $message_id)
    {
        $data = [
            "messaging_product" => "whatsapp",
            "recipient_type" => "individual",
            "to" => $phone,
            "context" => [
                "message_id" => $message_id
            ],
            "type" => "text",
            "text" => [
                "preview_url" => false,
                "body" => $messages
            ]
        ];

        if ($data) {
            $responseData = baseUrl($Version, $PhoneID, $token, $data);
            if ($responseData) {
                return response()->json("data Send Messages", 200);
            } else {
                return response()->json("data Error Send Messages", 400);
            }
        }
        return false;
    }
}

if (!function_exists('sendListMessagesSingle')) {
    function sendListMessagesSingle($Version, $PhoneID, $token, $phone, $list_id)
    {
        $list = BootList::findorfail($list_id);
        $rows = [];

        foreach ($list->questionList as $questionList) {
            $row = [
                "id" => $questionList->id,
                "title" => $questionList->title,
                "description" => $questionList->description
            ];
            $rows[] = $row;
        }
        $data = [
            "messaging_product" => "whatsapp",
            "recipient_type" => "individual",
            "to" => $phone,
            "type" => "interactive",
            "interactive" => [
                "type" => "list",
                "header" => [
                    "type" => "text",
                    "text" => $list->header_text
                ],
                "body" => [
                    "text" => $list->body_text ?? null
                ],
                "footer" => [
                    "text" => $list->footer_text ?? null
                ],
                'action' => [
                    'button' => $list->button_text,
                    'sections' => [
                        [
                            "title" => $list->section_1_title,
                            "rows" => $rows
                        ]
                    ]
                ]
            ]
        ];

        if ($data) {
            $responseData = baseUrl($Version, $PhoneID, $token, $data);
            if ($responseData) {
                return response()->json("data Send Messages", 200);
            } else {
                return response()->json("data Error Send Messages", 400);
            }
        }
        return false;
    }
}

if (!function_exists('sendReplyListSingle')) {
    function sendReplyListSingle($Version, $PhoneID, $token, $phone, $list_id, $message_id)
    {
        $list = BootList::findorfail($list_id);
        $rows = [];

        foreach ($list->questionList as $questionList) {
            $row = [
                "id" => $questionList->row_id,
                "title" => $questionList->row_title,
                "description" => $questionList->row_description
            ];
            $rows[] = $row;
        }
        $data = [
            "messaging_product" => "whatsapp",
            "recipient_type" => "individual",
            "to" => $phone,
            "context" => [
                "message_id" => $message_id
            ],
            "type" => "interactive",
            "interactive" => [
                "type" => "list",
                "header" => [
                    "type" => "text",
                    "text" => $list->header_text
                ],
                "body" => [
                    "text" => $list->body_text ?? null
                ],
                "footer" => [
                    "text" => $list->footer_text ?? null
                ],
                'action' => [
                    'button' => $list->button_text,
                    'sections' => [
                        [
                            "title" => $list->section_1_title,
                            "rows" => $rows
                        ]
                    ]
                ]
            ]
        ];
        if ($data) {
            $responseData = baseUrl($Version, $PhoneID, $token, $data);
            if ($responseData) {
                return response()->json("data Send Messages", 200);
            } else {
                return response()->json("data Error Send Messages", 400);
            }
        }
        return false;
    }
}

if (!function_exists('sendButtonSingle')) {
    function sendButtonSingle($Version, $PhoneID, $token, $phone, $id_button)
    {
        $findButton = BootButton::findorfail($id_button);

        $buttons = [];
        foreach ($findButton->ReplyButton as $ReplyButton) {
            $button = [
                "type" => "reply",
                "reply" => [
                    "id" => $ReplyButton->id,
                    "title" => $ReplyButton->button_title
                ]
            ];
            $buttons[] = $button;
        }

        $data = [
            "messaging_product" => "whatsapp",
            "recipient_type" => "individual",
            "to" => $phone,
            "type" => "interactive",
            "interactive" => [
                "type" => "button",
                "body" => [
                    "text" => $findButton->button_text
                ],
                "action" => [
                    "buttons" => $buttons
                ]
            ]
        ];

        if ($data) {
            $responseData = baseUrl($Version, $PhoneID, $token, $data);
            if ($responseData) {
                return response()->json("data Send Messages", 200);
            } else {
                return response()->json("data Error Send Messages", 400);
            }
        }
        return false;
    }
}


if (!function_exists('sendDocument')) {
    function sendDocument($Version, $PhoneID, $token, $phone, $document)
    {
        $data = [
            "messaging_product" => "whatsapp",
            "recipient_type" => "individual",
            "to" => $phone,
            "type" => "document",
            "document" => [
                "id" => "id",
                "caption" => "caption",
                "filename" => "filename",

            ]
        ];

        if ($data) {
            $responseData = baseUrl($Version, $PhoneID, $token, $data);
            if ($responseData) {
                return response()->json("data Send Messages", 200);
            } else {
                return response()->json("data Error Send Messages", 400);
            }
        }
        return false;
    }
}

if (!function_exists('sendTemplate')) {
    function sendTemplate($Version, $PhoneID, $token, $phone, $id_template)
    {
        $template = Template::findorfail($id_template);
        $data = [
            "messaging_product" => "whatsapp",
            "recipient_type" => "individual",
            "to" => $phone,
            "type" => "template",
            "template" => [
                "name" => $template->name,
                "language" => [
                    "code" => $template->language
                ]
            ]
        ];

        if ($data) {
            $responseData = baseUrl($Version, $PhoneID, $token, $data);
            if ($responseData) {
                return response()->json("data Send Messages", 200);
            } else {
                return response()->json("data Error Send Messages", 400);
            }
        }
        return false;
    }
}


