<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\BootButton;
use App\Models\BootList;
use App\Models\channel;
use App\Models\ExtractionApi;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Session;

class ApiWorkController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $data = getInformationData('ExtractionApi');
        return view('admin.apiWork.index', compact('data'));
    }


    public function store(Request $request)
    {
        try {
            $data = ExtractionApi::create([
                'user_id' => auth('web')->check() ? getUserType() : null,
                'subscriber_id' => auth('subscriber')->check() ? getUserType() : null,
                'boot_list_id' => $request->boot_list_id,
                'boot_button_id' => $request->boot_button_id,
                'channel_id' => $request->channel_id,
                'status' => 'active',
                'url' => null,
            ]);

            if ($data) {
                $phone = 20111111111;
                $chanel = channel::findorfail($request->channel_id);
                if ($request->boot_list_id) {
                    $url = $this->ListMessagesSingle($request->boot_list_id, $phone);
                } else {
                    $url = $this->ButtonSingle($request->boot_button_id, $phone);
                }

                $updated = $this->baseUrlApi($chanel->token, $url, $chanel->version, $chanel->number_id);
                ExtractionApi::findorfail($data->id)->update([
                    'url' => $updated,
                ]);
            }


            Session::flash('message', 'تم الحفظ بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->back();
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }


    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        ExtractionApi::destroy(\request()->id);
        Session::flash('message', 'تم الحذف بنجاح');
        Session::flash('alert-class', 'alert-success');
        return redirect()->back();
    }

    protected function ListMessagesSingle($list_id, $phone)
    {
        $list = BootList::findorfail($list_id);
        $rows = [];

        foreach ($list->questionList as $questionList) {
            $row = [
                'id' => $questionList->id,
                'title' => $questionList->title,
                'description' => $questionList->description
            ];
            $rows[] = $row;
        }
        $data = [
            'messaging_product' => 'whatsapp',
            'recipient_type' => 'individual',
            'to' => $phone,
            'type' => 'interactive',
            'interactive' => [
                'type' => 'list',
                'header' => [
                    'type' => 'text',
                    'text' => $list->header_text
                ],
                'body' => [
                    'text' => $list->body_text ?? null
                ],
                'footer' => [
                    'text' => $list->footer_text ?? null
                ],
                'action' => [
                    'button' => $list->button_text,
                    'sections' => [
                        [
                            'title' => $list->section_1_title,
                            'rows' => $rows
                        ]
                    ]
                ]
            ]
        ];
        return $data;
    }

    protected function ButtonSingle($id_button, $phone)
    {
        $findButton = BootButton::findorfail($id_button);

        $buttons = [];
        foreach ($findButton->ReplyButton as $ReplyButton) {
            $button = [
                'type' => 'reply',
                'reply' => [
                    'id' => $ReplyButton->id,
                    'title' => $ReplyButton->button_title
                ]
            ];
            $buttons[] = $button;
        }

        $data = [
            'messaging_product' => 'whatsapp',
            'recipient_type' => 'individual',
            'to' => $phone,
            'type' => 'interactive',
            'interactive' => [
                'type' => 'button',
                'body' => [
                    'text' => $findButton->button_text
                ],
                'action' => [
                    'buttons' => $buttons
                ]
            ]
        ];

        return $data;
    }

    protected function baseUrlApi($token, $data, $Version, $PhoneID)
    {

        $data_json = json_encode($data);
        $url = "curl -i -X POST https://graph.facebook.com/{$Version}/{$PhoneID}/messages " .
            "-H 'Authorization: Bearer {$token}' " .
            "-H 'Content-Type: application/json' " .
            "-d '{$data_json}'";

        return $url;
    }

}
