<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\ReplyBoot;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\Session;

class ChatBootController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $data = getInformationData('ReplyBoot');
        return view('admin.chatboot.index',compact('data'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        try {

            if ($request->boot_list_id != null && $request->boot_button_id != null){
                return redirect()->back()->withErrors(['error' => 'يجب اختيار شي واحد فقط']);
            }

            $check = ReplyBoot::where('status' ,'yes')->first();

            if ($check){
                if ($request->boot_button_id == $check->boot_button_id){
                    return redirect()->back()->withErrors(['error' => 'لقد تم اضافه هذا البوت من قبل']);
                }
            }


            ReplyBoot::create([
                'user_id' => auth('web')->check() ?  getUserType() : null,
                'subscriber_id' => auth('subscriber')->check() ?  getUserType() : null,
                'name'=> $request->name,
                'boot_list_id'=> $request->boot_list_id ?? null,
                'boot_button_id'=> $request->boot_button_id ?? null,
                "type" => $request->boot_list_id ? 'list' : 'button',
                'status' => 'yes',

            ]);
            Session::flash('message', 'تم الحفظ بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->back();
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        try {
            $data = ReplyBoot::findorfail($id);
            if ($data->type == "messages"){
                return redirect()->back()->withErrors(['error' => 'لا يوجد ردود على هذا النوع']);
            }
            return view('admin.chatboot.show',compact('data'));
        }catch (\Exception $exception){
            return redirect()->back()->withErrors(['error' => 'لا يوجد ردود على هذا النوع']);
        }


    }

    public function chatBootMessages(Request $request)
    {
        try {


            ReplyBoot::create([
                'user_id' => auth('web')->check() ?  getUserType() : null,
                'subscriber_id' => auth('subscriber')->check() ?  getUserType() : null,
                'reply_boot_id'=> $request->id_reply_message,
                'reply_message_id'=> $request->message_id,
                'reply_boot_button_id'=> $request->message_id,
                'type' => 'messages',
                'status' => 'no',

            ]);
            Session::flash('message', 'تم الحفظ بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->back();
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    public function edit(string $id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        try {
            ReplyBoot::destroy(\request()->id);
            Session::flash('message', 'تم الحذف بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->back();
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }
}
