<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\BootButton;
use App\Models\BootList;
use App\Models\ChanelEmployee;
use App\Models\channel;
use App\Models\Client;
use App\Models\ReplyBoot;
use App\Models\SingleMessages;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Session;

class ClientsController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        try {
            $data = getInformationDataPaginationClient('Client');
            return view('admin.clients.index', compact('data'));
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => 'في انتظار تحويل عملاء لك']);
        }


    }

    public function sendMessages(Request $request)
    {
        try {
            $client = Client::findorfail($request->id);
            $whatsapp = channel::findorfail($client->channel_id);
            SingleMessages::create([
                'user_id' => auth('web')->check() ? getUserType() : null,
                'subscriber_id' => auth('subscriber')->check() ? getUserType() : null,
                'employee_id' => auth('employee')->check() ? getUserType() : null,
                'channel_id' => Client::findorfail($request->id)->first()->channel_id,
                'client_id' => $request->id,
                'messages' => $request->message,
                'type' => "sender_messages",
                'status' => "read",
            ]);
            sendMessages($whatsapp->version, $whatsapp->number_id, $whatsapp->token, $client->phone, $request->message);

            return response()->json(['message' => 'تم الارسال بنجاح بنجاح']);
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {

        $data = [];

        if (auth('web')->check()) {
            $data['channels'] = channel::all();
        }

        if (auth('subscriber')->check() || auth('employee')->check()) {
            $subscriberId = auth('subscriber')->user()->id;
            $data['subscriberChannels'] = channel::where('subscriber_id', $subscriberId)->get();
        }

        return view('admin.clients.create', compact('data'));

    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $request->validate([
            'phone' => 'required|unique:clients,phone'
        ]);
        try {
            Client::create([
                'user_id' => auth('web')->check() ? getUserType() : null,
                'subscriber_id' => auth('subscriber')->check() ? getUserType() : null,
                'employee_id' => auth('employee')->check() ? getUserType() : null,
                'status_id' => 3,
                'channel_id' => $request->channel_id ?? null,
                'name' => $request->name,
                'phone' => $request->phone,
                'status_boot' => 'active',
                'start_date' => Carbon::now(),
            ]);
            Session::flash('message', 'تم الحفظ بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->route('clients.index');
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        $data = Client::findorfail($id);
        $data->messages()->update([
            "status" => 'read'
        ]);
        return view('admin.clients.chat', compact('data'));
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $information = [];
        if (auth('web')->check()) {
            $information['channels'] = channel::all();
        }
        if (auth('subscriber')->check() || auth('employee')->check()) {
            $subscriberId = auth('subscriber')->id();
            $information['subscriberChannels'] = channel::where('subscriber_id', $subscriberId)->get();
        }
        $data = Client::whereUuid($id)->first();


        return view('admin.clients.edit', compact('information', 'data'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {

        $request->validate([
            'phone' => 'required|unique:clients,phone,' . $request->uuid . ',uuid'
        ]);
        try {
            Client::findorfail($request->uuid)->update([
                'user_id' => auth('web')->check() ? getUserType() : null,
                'subscriber_id' => auth('subscriber')->check() ? getUserType() : null,
                'employee_id' => auth('employee')->check() ? getUserType() : null,
                'channel_id' => $request->channel_id ?? null,
                'name' => $request->name,
                'phone' => $request->phone,
                'status_boot' => 'active',
                'start_date' => Carbon::now(),
            ]);
            Session::flash('message', 'تم التعديل بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->route('clients.index');
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        try {
            Client::destroy(\request()->id);
            Session::flash('message', 'تم الحذف بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->route('clients.index');
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    public function clientsChange(Request $request)
    {
        try {
            Client::findorfail($request->id)->update([
                "employee_id" => $request->employee_id,
            ]);
            Session::flash('message', 'تم التحديث بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->route('clients.index');
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    public function changeStatus(Request $request)
    {
        try {
            Client::findorfail($request->id)->update([
                "status_id" => $request->status_id,
            ]);
            Session::flash('message', 'تم التحديث بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->route('clients.index');
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    public function sendNewMessages(Request $request)
    {

        try {
            $whatsapp = channel::findorfail($request->whatsapp_id);

            foreach (explode(',', $request->delete_all_id) as $row) {
                $client = Client::findorfail($row);

                if ($request->type == "button") {
                    $findBoot = ReplyBoot::findOrFail($request->send_button_id);

                    sendButtonSingle($whatsapp->version, $whatsapp->number_id, $whatsapp->token, $client->phone, $findBoot->boot_button_id);
                    SingleMessages::create([
                        'user_id' => optional($whatsapp->user)->id,
                        'subscriber_id' => optional($whatsapp->subscriber)->id,
                        'employee_id' => null,
                        'channel_id' => $whatsapp->id,
                        'client_id' => $row,
                        'messages' => BootButton::findOrFail($findBoot->boot_button_id)->button_text,
                        'type' => 'sender_messages',
                        'status' => 'noRead',
                    ]);
                } else {
                    sendMessages($whatsapp->version, $whatsapp->number_id, $whatsapp->token, $client->phone, $request->messages);

                    SingleMessages::create([
                        'user_id' => optional($whatsapp->user)->id,
                        'subscriber_id' => optional($whatsapp->subscriber)->id,
                        'employee_id' => null,
                        'channel_id' => $whatsapp->id,
                        'client_id' => $row,
                        'messages' => $request->messages,
                        'type' => 'sender_messages',
                        'status' => 'noRead',
                    ]);
                }
            }

            Session::flash('message', 'تم الارسال بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->route('clients.index');
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    public function transformationEmployee(Request $request)
    {
        try {
            foreach (explode(',', $request->delete_all_id) as $row) {
                Client::findorfail($row)->update([
                    'employee_id' => $request->employee_id
                ]);
            }
            Session::flash('message', 'تم تحويل العملاء بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->route('clients.index');
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    public function sendBootInClient(Request $request)
    {
        try {
            $client = Client::findorfail($request->id);
            $whatsapp = channel::findorfail($client->channel_id);
            $findBoot = ReplyBoot::findOrFail($request->send_button_id);

            if ($findBoot->type == "list") {

                sendListMessagesSingle($whatsapp->version, $whatsapp->number_id, $whatsapp->token, $client->phone, $findBoot->boot_list_id);

                SingleMessages::create([
                    'user_id' => optional($whatsapp->user)->id,
                    'subscriber_id' => optional($whatsapp->subscriber)->id,
                    'employee_id' => null,
                    'channel_id' => $whatsapp->id,
                    'client_id' => $request->id,
                    'messages' => BootList::findOrFail($findBoot->boot_list_id)->name,
                    'type' => 'sender_messages',
                    'status' => 'noRead',
                ]);

                Session::flash('message', 'تم الارسال بنجاح');
                Session::flash('alert-class', 'alert-success');
                return redirect()->route('clients.index');
            } else {
                sendButtonSingle($whatsapp->version, $whatsapp->number_id, $whatsapp->token, $client->phone, $findBoot->boot_button_id);
                SingleMessages::create([
                    'user_id' => optional($whatsapp->user)->id,
                    'subscriber_id' => optional($whatsapp->subscriber)->id,
                    'employee_id' => null,
                    'channel_id' => $whatsapp->id,
                    'client_id' => $request->id,
                    'messages' => BootButton::findOrFail($findBoot->boot_button_id)->button_text,
                    'type' => 'sender_messages',
                    'status' => 'noRead',
                ]);

                Session::flash('message', 'تم الارسال بنجاح');
                Session::flash('alert-class', 'alert-success');
                return redirect()->route('clients.index');
            }

        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    public function getUnreadClients(Request $request)
    {
        $unreadClients = getInformationDataQquery('Client')->with('messages')->whereHas('messages', function ($query) {
            $query->where('status', 'noRead');
        })->get();

        return response()->json($unreadClients);
    }
    public function hiringClients()
    {
        $getChanel = ChanelEmployee::where('employee_id', auth('employee')->id())->first()->channel_id;
        $data = Client::where('channel_id',$getChanel)->paginate(50);
        return view('admin.clients.index',compact('data'));
    }
}
